# nsst

Python library for a Not So Simple Table dynamodb table design.

## Description

`nsst` is a simple library to help make working with DynamoDB a bit easier.

## Getting started

Install via pip (ideally in a virtualenv):

```bash
pip install nsst
```
